Test coverage report: hero_slider.tests.test_app.models

# hero_slider.tests.test_app.models: 3 total statements, 100.0% covered

Generated: Thu 2013-04-18 14:15 SGT

Source file: /Users/martin/Repos/django-hero-slider/hero_slider/tests/test_app/models.py

Stats: 2 executed, 0 missed, 1 excluded, 4 ignored

1. `"""Dummy models for the tests of the ``hero_slider`` app."""`
2. `from django.db import models`
3. ``
4. ``
5. `class DummyModel(models.Model):`
6. `"""DummyModel for tests of the ``hero_slider`` app."""`
7. `name = models.CharField(max_length=256)`